@@ -27,6 +27,11 @@ sub bar {
 
     print "The called package from the first line of the first backtrace:\n";
     print $backtrace1->point(0)->called_package, "\n";
+
+    my $backtrace4 = Devel::Backtrace->new(-start => 1,
+        -format => 'subroutine %s, package %c from %p');
+    print "bar call in different format:\n";
+    print $backtrace4->point(0);
 }
 
 
@@ -39,20 +44,20 @@ Output:
 First backtrace:
 Devel::Backtrace::new called from main (examples/basic.pl:12)
 main::bar called from main (examples/basic.pl:8)
-main::foo called from main (examples/basic.pl:33)
+main::foo called from main (examples/basic.pl:38)
 
 Second (shorter) backtrace:
 main::bar called from main (examples/basic.pl:8)
-main::foo called from main (examples/basic.pl:33)
+main::foo called from main (examples/basic.pl:38)
 
 Third (even shorter) backtrace:
-main::foo called from main (examples/basic.pl:33)
+main::foo called from main (examples/basic.pl:38)
 
 The third backtrace in a very long form:
 (Note that the bitmask may depend on the perl version.)
 package: main
 filename: examples/basic.pl
-line: 33
+line: 38
 subroutine: main::foo
 hasargs: 1
 wantarray: undef
@@ -66,3 +71,6 @@ The line number from the second line of the first backtrace:
 
 The called package from the first line of the first backtrace:
 Devel::Backtrace
+
+bar call in different format:
+subroutine main::bar, package main from main
